@@ -1,4 +1,3 @@
-
 =head1 NAME
 
 Module::Starter::Plugin::CGIApp - template based module starter for CGI apps.
@@ -34,17 +33,17 @@ use HTML::Template;
 
 =head1 VERSION
 
-This document describes version 0.40
+This document describes version 0.43
 
 =cut
 
-our $VERSION = '0.40';
+our $VERSION = '0.43';
 
 =head1 DESCRIPTION
 
 This module subclasses L<Module::Starter::Simple|Module::Starter::Simple> and
 includes functionality similar to L<Module::Starter::Plugin::Template|Module::Starter::Plugin::Template>.
-This document only describes the methods which are overriden from those modules or are new.
+This document only describes the methods which are overridden from those modules or are new.
 
 Only developers looking to extend this module need to read this. If you just 
 want to use L<Module::Starter::Plugin::CGIApp|Module::Starter::Plugin::CGIApp>, read the docs for 
@@ -263,7 +262,7 @@ sub create_t {
 
     my %t_files = $self->t_guts(@modules);
 
-    my @files = map { $self->_create_t( $_, $t_files{$_} ) } keys %t_files;
+    my @files = map { $self->_create_t( 't',  $_, $t_files{$_} ) }  keys %t_files;
 
     # This next part is for the static files dir t/www
     my @dirparts = ( $self->{basedir}, 't', 'www' );
@@ -310,28 +309,11 @@ sub create_xt {
 
     my %xt_files = $self->xt_guts(@modules);
 
-    my @files = map { $self->_create_xt( $_, $xt_files{$_} ) } keys %xt_files;
+    my @files = map { $self->_create_t( 'xt', $_, $xt_files{$_} ) } keys %xt_files;
 
     return @files;
 }
 
-sub _create_xt {
-    my ( $self, $filename, $content ) = @_;
-
-    my @dirparts = ( $self->{basedir}, 'xt' );
-    my $xtdir = File::Spec->catdir(@dirparts);
-    if ( not -d $xtdir ) {
-        mkpath($xtdir);
-        $self->progress("Created $xtdir");
-    }
-
-    my $fname = File::Spec->catfile( @dirparts, $filename );
-    $self->create_file( $fname, $content );
-    $self->progress("Created $fname");
-
-    return "xt/$filename";
-}
-
 =head2 render( $template, \%options )
 
 This method is given an L<HTML::Template|HTML::Template> and options and
@@ -489,9 +471,9 @@ This distribution is free software; you can redistribute it and/or modify it
 under the terms of either:
 
 a) the GNU General Public License as published by the Free Software
-Foundation; either version 2, or (at your option) any later version, or
+Foundation; either version 1, or (at your option) any later version, or
 
-b) the Artistic License version 2.0.
+b) the Artistic License version 1.0 or a later version.
 EOT
         }
         else {
@@ -716,15 +698,15 @@ Jaldhar H. Vyas, E<lt>jaldhar at braincells.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2012, Consolidated Braincells Inc.  All Rights Reserved.
+Copyright (C) 2015, Consolidated Braincells Inc.  All Rights Reserved.
 
 This distribution is free software; you can redistribute it and/or modify it
 under the terms of either:
 
 a) the GNU General Public License as published by the Free Software
-Foundation; either version 2, or (at your option) any later version, or
+Foundation; either version 1, or (at your option) any later version, or
 
-b) the Artistic License version 2.0.
+b) the Artistic License version 1.0 or a later version.
 
 The full text of the license can be found in the LICENSE file included
 with this distribution.
